@@ -1,5 +1,5 @@
 mod _ref {
-    use crate::{signature::decode, SignatureRef};
+    use crate::{signature::decode, Signature, SignatureRef};
 
     impl<'a> SignatureRef<'a> {
         /// Deserialize a signature from the given `data`.
@@ -9,6 +9,15 @@ mod _ref {
         {
             decode(data).map(|(_, t)| t)
         }
+
+        /// Create an owned instance from this shared one.
+        pub fn to_owned(&self) -> Signature {
+            Signature {
+                name: self.name.to_owned(),
+                email: self.email.to_owned(),
+                time: self.time,
+            }
+        }
     }
 }
 
@@ -34,6 +43,15 @@ mod convert {
                 },
             }
         }
+
+        /// Borrow this instance as immutable
+        pub fn to_ref(&self) -> SignatureRef<'_> {
+            SignatureRef {
+                name: self.name.as_ref(),
+                email: self.email.as_ref(),
+                time: self.time,
+            }
+        }
     }
 
     impl From<SignatureRef<'_>> for Signature {
@@ -46,17 +64,6 @@ mod convert {
             }
         }
     }
-
-    impl Signature {
-        /// Borrow this instance as immutable
-        pub fn to_ref(&self) -> SignatureRef<'_> {
-            SignatureRef {
-                name: self.name.as_ref(),
-                email: self.email.as_ref(),
-                time: self.time,
-            }
-        }
-    }
 }
 
 mod write {
@@ -65,7 +72,7 @@ mod write {
     use bstr::{BStr, ByteSlice};
     use quick_error::quick_error;
 
-    use crate::{Signature, SPACE};
+    use crate::{Signature, SignatureRef, SPACE};
 
     quick_error! {
         /// The Error produced by [`Signature::write_to()`].
@@ -86,12 +93,19 @@ mod write {
 
     /// Output
     impl Signature {
+        /// Serialize this instance to `out` in the git serialization format for actors.
+        pub fn write_to(&self, out: impl io::Write) -> io::Result<()> {
+            self.to_ref().write_to(out)
+        }
+    }
+
+    impl<'a> SignatureRef<'a> {
         /// Serialize this instance to `out` in the git serialization format for actors.
         pub fn write_to(&self, mut out: impl io::Write) -> io::Result<()> {
-            out.write_all(validated_token(self.name.as_bstr())?)?;
+            out.write_all(validated_token(self.name)?)?;
             out.write_all(SPACE)?;
             out.write_all(&b"<"[..])?;
-            out.write_all(validated_token(self.email.as_bstr())?)?;
+            out.write_all(validated_token(self.email)?)?;
             out.write_all(&b"> "[..])?;
             self.time.write_to(out)?;
             Ok(())
